macro_rules! sel_expr {
($($expr:expr),+ $(,)?) => { ... };
}Expand description
selector
equivalent of calling AbstractExpression::<F>::select_seq(vec![<INPUTS>])
but allows the entries to be of different type
macro_rules! sel_expr {
($($expr:expr),+ $(,)?) => { ... };
}selector
equivalent of calling AbstractExpression::<F>::select_seq(vec![<INPUTS>])
but allows the entries to be of different type